@@ -41,11 +41,11 @@ setConstructorS3("HaarSegModel", function(cesTuple=NULL, ..., breaksFdrQ=0.0001)
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   if (!is.null(cesTuple)) {
     # Early error, iff package is not installed
-    requireNamespace("HaarSeg") || throw("Package not loaded: HaarSeg");
+    requireNamespace("HaarSeg") || throw("Package not loaded: HaarSeg")
   }
 
   # Argument 'breaksFdrQ':
-  breaksFdrQ <- Arguments$getDouble(breaksFdrQ, range=c(0,1));
+  breaksFdrQ <- Arguments$getDouble(breaksFdrQ, range=c(0,1))
 
   extend(CopyNumberSegmentationModel(cesTuple=cesTuple, ...), "HaarSegModel",
     .breaksFdrQ = breaksFdrQ
@@ -54,29 +54,10 @@ setConstructorS3("HaarSegModel", function(cesTuple=NULL, ..., breaksFdrQ=0.0001)
 
 
 setMethodS3("getAsteriskTags", "HaarSegModel", function(this, ...) {
-  NextMethod("getAsteriskTags", tag="HAAR");
+  NextMethod("getAsteriskTags", tag="HAAR")
 }, protected=TRUE)
 
 
 setMethodS3("getFitFunction", "HaarSegModel", function(this, ...) {
-  segmentByHaarSeg;
+  segmentByHaarSeg
 }, protected=TRUE)
-
-
-##############################################################################
-# HISTORY:
-# 2009-05-16
-# o Added getFitFunction().  Removed fitOne().
-# 2008-05-14
-# o Moved drawCnRegions(), extractCopyNumberRegions() and
-#   extractRawCopyNumbers() for HaarSeg to aroma.core v1.0.6 (will
-#   eventually end up in aroma.cn).
-# 2008-01-26
-# o Reordered constructor arguments.
-# 2008-12-31
-# o Removing non-finite data points before passing to haarSeg().
-# 2008-12-17
-# o Now using the HaarSeg package (put together by HB).
-# 2008-12-16
-# o Created.
-##############################################################################
