@@ -83,13 +83,13 @@ setMethodS3("colBinnedSmoothing", "matrix", function(Y, x=seq_len(nrow(Y)), w=NU
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
   # Argument 'Y'
-  n <- nrow(Y);
-  k <- ncol(Y);
+  n <- nrow(Y)
+  k <- ncol(Y)
   
   # Argument 'x'
   if (length(x) != n) {
     throw("Argument 'x' has different number of values than rows in 'Y': ", 
-                                                     length(x), " != ", n);
+                                                     length(x), " != ", n)
   }
 
   # Argument 'w'
@@ -97,74 +97,74 @@ setMethodS3("colBinnedSmoothing", "matrix", function(Y, x=seq_len(nrow(Y)), w=NU
   } else {
     if (length(w) != n) {
       throw("Argument 'w' has different number of values than rows in 'Y': ", 
-                                                       length(w), " != ", n);
+                                                       length(w), " != ", n)
     }
   }
 
   # Argument 'from' & 'to':
   if (is.null(xOut) && is.null(xOutRange)) {
-    disallow <- c("NA", "NaN", "Inf");
-    from <- Arguments$getNumeric(from, disallow=disallow);
-    to <- Arguments$getNumeric(to, range=c(from,Inf), disallow=disallow);
+    disallow <- c("NA", "NaN", "Inf")
+    from <- Arguments$getNumeric(from, disallow=disallow)
+    to <- Arguments$getNumeric(to, range=c(from,Inf), disallow=disallow)
   }
 
   # Arguments 'by' & 'length.out':
   if (is.null(by) & is.null(length.out)) {
-    throw("Either argument 'by' or 'length.out' needs to be given.");
+    throw("Either argument 'by' or 'length.out' needs to be given.")
   }
   if (n > 1 && !is.null(by)) {
-    by <- Arguments$getNumeric(by, range=c(0,Inf));
+    by <- Arguments$getNumeric(by, range=c(0,Inf))
   }
   if (!is.null(length.out)) {
-    length.out <- Arguments$getInteger(length.out, range=c(0,Inf));
+    length.out <- Arguments$getInteger(length.out, range=c(0,Inf))
   }
 
   # Argument 'xOut':
   if (!is.null(xOut)) {
-    xOut <- Arguments$getNumerics(xOut);
-#    o <- order(xOut);
+    xOut <- Arguments$getNumerics(xOut)
+#    o <- order(xOut)
 #    if (!all(diff(o) > 0L)) {
-#      throw("Argument 'xOut' must be strictly ordered: ", hpaste(na.omit(xOut)));
+#      throw("Argument 'xOut' must be strictly ordered: ", hpaste(na.omit(xOut)))
 #    }
   }
 
   # Argument 'xOut':
   if (!is.null(xOutRange)) {
     if (!is.matrix(xOutRange)) {
-      throw("Argument 'xOutRange' must be a matrix: ", hpaste(class(xOutRange)));
+      throw("Argument 'xOutRange' must be a matrix: ", hpaste(class(xOutRange)))
     }
     if (ncol(xOutRange) != 2L) {
-      throw("Argument 'xOutRange' must be a matrix with two columns: ", ncol(xOutRange));
+      throw("Argument 'xOutRange' must be a matrix with two columns: ", ncol(xOutRange))
     }
-    stopifnot(all(xOutRange[,2L] >= xOutRange[,1L]));
+    .stop_if_not(all(xOutRange[,2L] >= xOutRange[,1L]))
   }
 
   # Arguments 'na.rm':
-  na.rm <- Arguments$getLogical(na.rm);
+  na.rm <- Arguments$getLogical(na.rm)
 
   # Arguments 'FUN':
   if (is.character(FUN)) {
     if (FUN == "median") {
-      FUN <- colWeightedMedians;
+      FUN <- colWeightedMedians
     } else if (FUN == "mean") {
-      FUN <- colWeightedMeans;
+      FUN <- colWeightedMeans
     } else {
-      throw("Unknown value of argument 'FUN': ", FUN);
+      throw("Unknown value of argument 'FUN': ", FUN)
     }
   } else if (is.function(FUN)) {
   } else {
-    throw("Argument 'FUN' is not a function: ", class(FUN)[1]);
+    throw("Argument 'FUN' is not a function: ", class(FUN)[1])
   }
 
   # Argument 'verbose':
-  verbose <- Arguments$getVerbose(verbose);
+  verbose <- Arguments$getVerbose(verbose)
   if (verbose) {
-    pushState(verbose);
-    on.exit(popState(verbose));
+    pushState(verbose)
+    on.exit(popState(verbose))
   }
 
 
-  verbose && enter(verbose, "Binned smoothing column by column");
+  verbose && enter(verbose, "Binned smoothing column by column")
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
   # Setup (precalculations)
@@ -174,31 +174,31 @@ setMethodS3("colBinnedSmoothing", "matrix", function(Y, x=seq_len(nrow(Y)), w=NU
     # Generate from bin boundaries, or by using seq()?
     if (!is.null(xOutRange)) {
       # Place in the center of the bins
-      xOut <- (xOutRange[,1L] + xOutRange[,2L]) / 2;
+      xOut <- (xOutRange[,1L] + xOutRange[,2L]) / 2
     } else {
       if (!is.null(by)) {
-        xOut <- seq(from=from, to=to, by=by);
+        xOut <- seq(from=from, to=to, by=by)
       } else {
-        xOut <- seq(from=from, to=to, length.out=length.out);
+        xOut <- seq(from=from, to=to, length.out=length.out)
       }
     }
   }
 
-  verbose && cat(verbose, "xOut:");
-  verbose && str(verbose, xOut);
+  verbose && cat(verbose, "xOut:")
+  verbose && str(verbose, xOut)
 
   # Number of bins
-  nOut <- length(xOut);
+  nOut <- length(xOut)
 
   # Make sure that 'xOut' (and 'xOutRange') are ordered before
   # binning.  Also make sure to undo afterward.
-  o <- order(xOut);
-  wasReordered <- (!all(diff(o) > 0L));
+  o <- order(xOut)
+  wasReordered <- (!all(diff(o) > 0L))
   if (wasReordered) {
-    ro <- order(o);
-    xOut <- xOut[o];
+    ro <- order(o)
+    xOut <- xOut[o]
     if (!is.null(xOutRange)) {
-      xOutRange <- xOutRange[o,,drop=FALSE];
+      xOutRange <- xOutRange[o,,drop=FALSE]
     }
   }
 
@@ -207,54 +207,54 @@ setMethodS3("colBinnedSmoothing", "matrix", function(Y, x=seq_len(nrow(Y)), w=NU
   if (is.null(xOutRange)) {
     # Average bin width
     if (is.null(by)) {
-      avgBinWidth <- mean(diff(xOut), na.rm=TRUE);
+      avgBinWidth <- mean(diff(xOut), na.rm=TRUE)
     } else {
-      avgBinWidth <- by;
+      avgBinWidth <- by
     }
 
     # Identify mid points between target locations
-    xOutMid <- (xOut[-1L] + xOut[-nOut]) / 2;
+    xOutMid <- (xOut[-1L] + xOut[-nOut]) / 2
 
     # The width of the first bin is twice the distance between
     # the first and the second 'xOut' such that xOut[1] is the
     # midpoint of (xOutRange[1,1], xOutRange[1,2]).  Likewise
     # for the last bin. /HB 2012-08-26
-    xOutMidFirst <- xOutMid[1L] - (xOut[2L] - xOut[1L]);
-    xOutMidLast <- xOutMid[nOut-1L] + (xOut[nOut] - xOut[nOut-1L]);
-    xOutMid <- c(xOutMidFirst, xOutMid, xOutMidLast);
+    xOutMidFirst <- xOutMid[1L] - (xOut[2L] - xOut[1L])
+    xOutMidLast <- xOutMid[nOut-1L] + (xOut[nOut] - xOut[nOut-1L])
+    xOutMid <- c(xOutMidFirst, xOutMid, xOutMidLast)
 
-    naValue <- as.double(NA);
-    xOutRange <- matrix(naValue, nrow=nOut, ncol=2);
-    xOutRange[,1L] <- xOutMid[-length(xOutMid)];
-    xOutRange[,2L] <- xOutMid[-1L];
+    naValue <- as.double(NA)
+    xOutRange <- matrix(naValue, nrow=nOut, ncol=2)
+    xOutRange[,1L] <- xOutMid[-length(xOutMid)]
+    xOutRange[,2L] <- xOutMid[-1L]
   } else {
     # Validate
     if (nrow(xOutRange) != nOut) {
-      throw("The number of rows in 'xOutRange' does not match the number of bin: ", ncol(xOutRange), " != ", nOut);
+      throw("The number of rows in 'xOutRange' does not match the number of bin: ", ncol(xOutRange), " != ", nOut)
     }
   }
 
   # Assert that the bin boundaries [x0,x1) contains the target bin.
-  stopifnot(all(xOutRange[,1L] <= xOut));
-  stopifnot(all(xOut <= xOutRange[,2L]));
+  .stop_if_not(all(xOutRange[,1L] <= xOut))
+  .stop_if_not(all(xOut <= xOutRange[,2L]))
 
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
   # Smoothing in bins
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
   # Allocate vector of smoothed signals
-  naValue <- as.double(NA);
-  Ys <- matrix(naValue, nrow=nOut, ncol=k);
-  colnames(Ys) <- colnames(Y);
+  naValue <- as.double(NA)
+  Ys <- matrix(naValue, nrow=nOut, ncol=k)
+  colnames(Ys) <- colnames(Y)
 
-  verbose && enter(verbose, "Estimating signals in each bin");
+  verbose && enter(verbose, "Estimating signals in each bin")
 
-  verbose && cat(verbose, "Output locations (bin centers):");
-  verbose && str(verbose, xOut);
+  verbose && cat(verbose, "Output locations (bin centers):")
+  verbose && str(verbose, xOut)
 
   # Speed up access access
-  x0 <- xOutRange[,1L, drop=TRUE];
-  x1 <- xOutRange[,2L, drop=TRUE];
+  x0 <- xOutRange[,1L, drop=TRUE]
+  x1 <- xOutRange[,2L, drop=TRUE]
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
   # Special cases?
@@ -262,140 +262,89 @@ setMethodS3("colBinnedSmoothing", "matrix", function(Y, x=seq_len(nrow(Y)), w=NU
 #  if (identical(FUN, colWeightedMeans) && is.null(w) && require("matrixStats")) {
 #    bx <- ...
 #    for (cc in seq_len(ncol(Y))) {
-#      ys <- matrixStats::binMeans(Y[,cc], x, bx=bx, na.rm=na.rm, count=(cc == 1L));
+#      ys <- matrixStats::binMeans(Y[,cc], x, bx=bx, na.rm=na.rm, count=(cc == 1L))
 #      if (cc == 1L) {
-#        counts <- attr(ys, "count");
+#        counts <- attr(ys, "count")
 #      }
-#      Ys[,cc] <- ys;
+#      Ys[,cc] <- ys
 #    } # for (cc ...)
 #  }
 
-  verbose && cat(verbose, "Summary of bin widths:");
-  verbose && print(verbose, summary(x1-x0));
+  verbose && cat(verbose, "Summary of bin widths:")
+  verbose && print(verbose, summary(x1-x0))
 
   # Allocate number of counts per bin
-  counts <- integer(nOut);
+  counts <- integer(nOut)
 
   # For each bin...
   for (kk in seq_len(nOut)) {
     if (kk %% 100 == 0)
-      verbose && cat(verbose, kk);
+      verbose && cat(verbose, kk)
 
     # Identify data points within the bin
-    keep <- which(x0[kk] <= x & x < x1[kk]);
-    nKK <- length(keep);
-    counts[kk] <- nKK;
+    keep <- which(x0[kk] <= x & x < x1[kk])
+    nKK <- length(keep)
+    counts[kk] <- nKK
 
     # Nothing to do?
     if (nKK == 0) {
-      next;
+      next
     }
 
     # Keep only data points and prior weight within the current bin
-    YBin <- Y[keep,,drop=FALSE];
+    YBin <- Y[keep,,drop=FALSE]
     if (is.null(w)) {
-      wBin <- NULL;
+      wBin <- NULL
     } else {
-      wBin <- w[keep];
+      wBin <- w[keep]
     }
 
-    value <- FUN(YBin, w=wBin, na.rm=na.rm);
+    value <- FUN(YBin, w=wBin, na.rm=na.rm)
 
     # Fix: Smoothing over a window with all missing values give zeros, not NA.
-    idxs <- which(value == 0);
+    idxs <- which(value == 0)
     if (length(idxs) > 0) {
       # Are these real zeros or missing values?
-      YBin <- YBin[idxs,,drop=FALSE];
-      YBin <- !is.na(YBin);
-      idxsNA <- idxs[colSums(YBin) == 0];    
-      value[idxsNA] <- as.double(NA);
+      YBin <- YBin[idxs,,drop=FALSE]
+      YBin <- !is.na(YBin)
+      idxsNA <- idxs[colSums(YBin) == 0]
+      value[idxsNA] <- as.double(NA)
     }
 
-#    verbose && str(verbose, value);
+#    verbose && str(verbose, value)
 
-    Ys[kk,] <- value;
+    Ys[kk,] <- value
   } # for (kk ...)
 
-  verbose && exit(verbose);
+  verbose && exit(verbose)
 
   # Undo reordering
   if (wasReordered) {
-    xOut <- xOut[ro];
-    xOutRange <- xOutRange[ro,,drop=FALSE];
-    Ys <- Ys[ro,,drop=FALSE];
+    xOut <- xOut[ro]
+    xOutRange <- xOutRange[ro,,drop=FALSE]
+    Ys <- Ys[ro,,drop=FALSE]
   }
 
   # Average bin width
-  avgBinWidth <- mean(xOutRange[,2L] - xOutRange[,1L], na.rm=TRUE);
+  avgBinWidth <- mean(xOutRange[,2L] - xOutRange[,1L], na.rm=TRUE)
 
-  attr(Ys, "xOut") <- xOut;
-  attr(Ys, "xOutRange") <- xOutRange;
-  attr(Ys, "counts") <- counts;
-  attr(Ys, "binWidth") <- avgBinWidth;
+  attr(Ys, "xOut") <- xOut
+  attr(Ys, "xOutRange") <- xOutRange
+  attr(Ys, "counts") <- counts
+  attr(Ys, "binWidth") <- avgBinWidth
 
   # Sanity check
-  stopifnot(nrow(Ys) == nOut);
+  .stop_if_not(nrow(Ys) == nOut)
 
-  verbose && exit(verbose);
+  verbose && exit(verbose)
 
-  Ys;
+  Ys
 }) # colBinnedSmoothing()
 
 
 
 setMethodS3("binnedSmoothing", "numeric", function(y, ...) {
-  y <- colBinnedSmoothing(as.matrix(y), ...);
-  dim(y) <- NULL;
-  y;
+  y <- colBinnedSmoothing(as.matrix(y), ...)
+  dim(y) <- NULL
+  y
 })
-
-
-
-############################################################################
-# HISTORY:
-# 2012-08-26
-# o BUG FIX: colBinnedSmoothing(..., xOut=xOut) could generate bins
-#   at the ends that did not contain the outer most 'xOut' values.
-# o BUG FIX: colBinnedSmoothing(..., xOut=xOut) would return binned
-#   values in the incorrect order, iff 'xOut' was not ordered.
-# o DOCUMENTATION: Clarified that when colBinnedSmoothing() is done over
-#   zero-length bins, the output for those bins will be NA.
-# 2012-03-14
-# o Now colNnnSmoothing() returns a matrix with column name as
-#   in argument 'Y'.
-# 2012-02-04
-# o GENERALIZATION: Now it is possible to call colBinnedSmoothing() with
-#   an empty set of input loci, but still requesting a set of output loci,
-#   which then will be all missing values.
-# o BUG FIX: Argument 'x' of colBinnedSmoothing() would default to the
-#   incorrect number of loci.
-# 2011-12-15
-# o Now colBinnedSmoothing() handles an unordered 'xOut'.
-# 2011-12-11
-# o ROBUSTNESS: colBinnedSmoothing() now asserts that 'xOut' is ordered.
-# 2011-12-10
-# o Returning also the bin counts.
-# o Now it is possible to fully specify the location and the width
-#   of each bin used by colBinnedSmoothing().
-# o Moved argument 'xOut' and new 'xOutRange' up front.
-# o DOCUMENTATION: Put 'from', 'to', 'by' and 'length.out' into one
-#   argument item and reference help for seq() as well.
-# o CORRECTNESS: Now bins are by default strictly disjoint, by redefining
-#   them as [x0,x1) instead of [x0,x1].
-# o CLEANUP: Dropped unused 'xDiff <- xDiff[keep]'.
-# 2009-05-16
-# o Now colBinnedSmoothing() uses Arguments$getNumerics(), not getDoubles(),
-#   where possible.  This will save memory in some cases.
-# 2009-05-12
-# o Now colBinnedSmoothing() assert that 'from' and 'to' are finite.
-# 2009-04-07
-# o BUG FIX: When passing a single data points to colBinnedSmoothing(),
-#   it would throw the exception: "Range of argument 'by' is out of range
-#   [0,0]: [<by>,<by>]".
-# 2009-03-23
-# o Replace argument 'robust' with more generic 'FUN'.
-# 2009-02-11
-# o Added more verbose output to colBinnedSmoothing().
-# 2009-02-07
-# o Created.
-############################################################################
